This corpus contains preprocessed posts from the Reddit dataset. The dataset
consists of 3,848,330 posts with an average length of 270 words for content, and
28 words for the summary.

Features includes strings: author, body, normalizedBody, content, summary,
subreddit, subreddit_id. Content is used as document and summary is used as
summary.
